A simplistic & configurable Markov chain text generator
Give it a vec of strings and generate random results. Works best with tweets, chat history, news headlines…
Minimal example:
use markov_strings::*;
let data: Vec<InputData> = vec![/* a lot of data */];
let mut markov = Markov::new();
markov.add_to_corpus(data);
let result: MarkovResult = markov.generate().unwrap();Structs
- Struct used to import and export data.
- The input struct to build the markov-strings corpus.
- The Markov chain generator
- Struct holding the generator’s results.
Enums
- Struct for possible errors during the corpus building, or result generation.